.. _api-queryset:

QuerySet
--------

Fetching Results
~~~~~~~~~~~~~~~~

.. _api-queryset-all:

``all()``
^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.all

.. _api-queryset-filter:

``filter``
^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.filter

.. _api-queryset-exclude:

``exclude``
^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.exclude

.. _api-queryset-update:

``update``
^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.update

.. _api-queryset-delete:

``delete``
^^^^^^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.delete

.. _api-queryset-update-all:

``update_all``
^^^^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.update_all

.. _api-queryset-delete-all:

``delete_all``
^^^^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.delete_all

.. _api-queryset-raw:

``raw``
^^^^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.raw

Fetch Options
~~~~~~~~~~~~~

.. _api-queryset-order-by:

``order_by``
^^^^^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.order_by

.. _api-queryset-limit:

``limit``
^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.limit

.. _api-queryset-offset:

``offset``
^^^^^^^^^^

.. automethod:: protean.core.queryset.QuerySet.offset
